package net.rzdata.demo.dict;

import com.baomidou.mybatisplus.core.metadata.IPage;
import net.rzdata.demo.dict.domain.AddDictReq;
import net.rzdata.demo.dict.domain.Dict;
import net.rzdata.demo.dict.domain.GetDictTypeListReq;
import net.rzdata.demo.dict.domain.UpdateDictReq;
import net.rzdata.domain.Id;
import org.springframework.web.bind.annotation.*;

import java.util.Collections;
import java.util.List;

@RestController
@RequestMapping("/dict")
public class DictController {

    private final DictService dictService;

    public DictController(DictService dictService) {
        this.dictService = dictService;
    }

    /**
     * 新增字典
     * @param req 新增字典请求
     * @return 新增字典的ID
     */
    @PostMapping()
    public Id addDict(@RequestBody AddDictReq req) {
        Dict dict = req.into();
        if (dict.getParentId() == null) {
            dict.setParentId(Dict.ROOT.getId());
            dict.setType(Dict.ROOT.getType());
        }
        dictService.addDict(dict);
        return Id.of(dict.getId());
    }

    /**
     * 更新字典
     * @param req 更新字典请求
     * @return 字典的ID
     */
    @PutMapping()
    public Id updateDict(@RequestBody UpdateDictReq req) {
        Dict dict = req.into();
        dictService.updateDict(dict);
        return Id.of(dict.getId());
    }

    /**
     * 获取字典类型列表
     * @param req 获取字典类型列表请求
     * @return 字典类型列表（分页）
     */
    @GetMapping("/type")
    public IPage<Dict> getDictTypePage(GetDictTypeListReq req) {
        return dictService.getDictTypePage(req);
    }

    /**
     * 获取字典树
     * @param parentId 父ID
     * @param level 层级
     * @return 字典树
     */
    @GetMapping("/tree")
    public List<Dict> getDictTree(
        @RequestParam(required = false, defaultValue = "0") String parentId,
        @RequestParam(required = false, defaultValue = "-1") Integer level
    ) {
        return dictService.getDictTreeTopDown(Collections.singleton(parentId), level);
    }

    /**
     * 获取字典数据
     * @param type 字典类型
     * @return 字典数据
     */
    @GetMapping("/data/{type}")
    public List<Dict> getDictData(@PathVariable String type) {
        return dictService.getDictByType(type);
    }

    /**
     * 获取字典数据
     * @param type 字典类型
     * @return 字典数据（树形结构）
     */
    @GetMapping("/data/{type}/tree")
    public List<Dict> getDictDataTree(@PathVariable String type) {
        return dictService.getDictByTypeAsTree(type);
    }

    @DeleteMapping("{id}")
    public void deleteDict(@PathVariable String id) {
        dictService.deleteDict(Collections.singleton(id));
    }
}
