package net.rzdata.demo.dict.domain;

import jakarta.validation.constraints.Max;
import jakarta.validation.constraints.NotNull;
import jakarta.validation.constraints.Pattern;
import lombok.Getter;
import lombok.Setter;
import lombok.ToString;
import net.rzdata.trait.IConverter;
import net.rzdata.trait.IQuery;
import org.mapstruct.Mapper;
import org.mapstruct.Mapping;
import org.mapstruct.factory.Mappers;

@Getter
@Setter
@ToString
public class AddDictReq implements IQuery<Dict> {

    /**
     * 字典标签
     */
    @Max(255)
    private String label;
    /**
     * 字典值
     */
    @Max(255)
    @NotNull(message = "字典值不能为空")
    @Pattern(regexp = "[\\w-]+", message = "字典值只允许英文字母、下划线、短横线")
    private String value;
    /**
     * 字典类型
     */
    @NotNull(message = "字典类型不能为空")
    private String type;
    /**
     * 父级ID
     * 如果是顶级字典 则为0
     */
    private String parentId;
    /**
     * 排序
     */
    @NotNull(message = "排序值不能为空")
    private Integer sort;
    /**
     * 是否禁用
     */
    private Boolean disabled;

    @Override
    public Dict into() {
        return AddDictReqConverter.INSTANCE.convert(this);
    }
}

@Mapper
interface AddDictReqConverter extends IConverter<AddDictReq, Dict> {

    AddDictReqConverter INSTANCE = Mappers.getMapper(AddDictReqConverter.class);

    @Mapping(target = "id", ignore = true)
    @Mapping(target = "children", ignore = true)
    @Override
    Dict convert(AddDictReq req);
}
