package net.rzdata.demo.dict.domain;

import jakarta.validation.constraints.Max;
import jakarta.validation.constraints.NotNull;
import jakarta.validation.constraints.Pattern;
import lombok.Getter;
import lombok.Setter;
import lombok.ToString;
import net.rzdata.trait.IConverter;
import net.rzdata.trait.IQuery;
import org.mapstruct.Mapper;
import org.mapstruct.Mapping;
import org.mapstruct.factory.Mappers;

@Getter
@Setter
@ToString
public class UpdateDictReq implements IQuery<Dict> {

    /**
     * 字典ID
     */
    private String id;
    /**
     * 字典标签
     */
    @Max(255)
    private String label;
    /**
     * 字典值
     */
    @Max(255)
    @NotNull(message = "字典值不能为空")
    @Pattern(regexp = "[\\w-]+", message = "字典值只允许英文字母、下划线、短横线")
    private String value;
    /**
     * 排序
     */
    @NotNull(message = "排序值不能为空")
    private Integer sort;
    /**
     * 父级ID
     */
    private String parentId;
    /**
     * 是否禁用
     */
    private Boolean disabled;

    public Dict into() {
        return UpdateDictReqConverter.INSTANCE.convert(this);
    }
}

@Mapper
interface UpdateDictReqConverter extends IConverter<UpdateDictReq, Dict> {

    UpdateDictReqConverter INSTANCE = Mappers.getMapper(UpdateDictReqConverter.class);

    @Mapping(target = "type", ignore = true)
    @Mapping(target = "children", ignore = true)
    @Override
    Dict convert(UpdateDictReq req);
}
