package net.rzdata.demo.dict.mapper;

import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.conditions.update.LambdaUpdateWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import net.rzdata.demo.dict.domain.Dict;
import net.rzdata.demo.dict.domain.GetDictTypeListReq;
import net.rzdata.demo.trait.BaseRepository;
import org.springframework.stereotype.Repository;

import java.util.Collection;
import java.util.List;

@Repository
public class DictRepository extends BaseRepository<Dict, DictMapper> {

    public DictRepository(DictMapper mapper) {
        super(mapper);
    }

    public List<Dict> findByTypeOrderBySortAsc(String type) {
        return this.get().selectList(new LambdaQueryWrapper<Dict>()
            .eq(Dict::getType, type)
            .orderByAsc(Dict::getSort)
        );
    }

    public int updateType(String oldValue, String newValue) {
        return this.get().update(null, new LambdaUpdateWrapper<Dict>()
            .set(Dict::getType, newValue)
            .eq(Dict::getType, oldValue)
        );
    }

    public List<Dict> findByParentIdIn(Collection<String> parentId) {
        return this.get().selectList(new LambdaQueryWrapper<Dict>()
            .in(Dict::getParentId, parentId)
            .orderByAsc(Dict::getSort)
        );
    }

    public IPage<Dict> getDictTypePage(GetDictTypeListReq req) {
        return this.get().selectPage(req.into(), new LambdaQueryWrapper<Dict>()
            .eq(Dict::getParentId, Dict.ROOT.getId())
            .orderByAsc(Dict::getSort)
        );
    }
}
